@@ -6,3 +6,10 @@ carsdt <- data.table::as.data.table(cars)
 carsdt <- data.table::as.data.table(cars)
 carsdt <- merge.data.table(cars)
 carsdt <- data.table::merge.data.table(cars)
+
+eqn <- "
+\\begin{equation*}
+\\overset
+  \\end{pmatrix}}
+"
+script <- readLines("inst/testdata/test_script.R")
